SyncDatabase class

Represents a database in RiviumSync

Constructors

SyncDatabase(MethodChannel _channel, String id, String name)

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Database ID
final
name String
Database name
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batch() WriteBatch
Create a new WriteBatch for atomic operations.
collection(String collectionIdOrName) SyncCollection
Get a collection reference by ID or name
createCollection(String name) Future<SyncCollection>
Create a new collection in this database
deleteCollection(String collectionId) Future<void>
Delete a collection
listCollections() Future<List<CollectionInfo>>
List all collections in this database
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited